@@ -1,15 +1,53 @@
 /* MAX_THREADS removed by Steve Underwood 1999/12/10 */
+#ifndef LIBDEFS_H
+# define LIBDEFS_H
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
+#ifdef HAVE_BYTESWAP_H
+# include <byteswap.h>
+#endif
+
+#ifdef HAVE_SYS_ENDIAN_H
+# include <sys/endian.h>
+#endif
+
+#ifdef HAVE_MACHINE_ENDIAN_H
+# include <machine/endian.h>
+#endif
+
+#ifdef HAVE_ENDIAN_H
+# include <endian.h>
+#endif
+
+
+#ifdef USE_LTDL
+# include "../libltdl/ltdl.h"
+#else
+# ifdef HAVE_DLFCN_H
+#  include <dlfcn.h>
+# endif
+# define lt_dlexit() 0
+# define lt_dlinit() 0
+# define lt_dlclose(x) dlclose(x)
+# define lt_dlsym(x,y) dlsym(x,y)
+# define lt_dlhandle void*
+# define lt_ptr_t void*
+# define lt_dlerror dlerror
+#endif
+
 #ifdef STDC_HEADERS
 # include <string.h>
 # include <stdlib.h>
 # include <stdio.h>
 #endif
 
+#ifdef HAVE_SYS_TYPES_H
+# include <sys/types.h>
+#endif
+
 #ifdef HAVE_DIRENT_H
 # include <dirent.h>
 #endif
@@ -58,3 +96,6 @@
 # endif
 #endif
 
+
+#endif /* LIBDEFS_H */
+
