@@ -17,6 +17,10 @@
 /* The header above modified on August 12th 1999.                       */
 /* Dr Brian Gladman (gladman@seven77.demon.co.uk) 12th August 1999      */
 
+#include "../../lib/libdefs.h"
+#include "../../lib/mcrypt_modules.h"
+
+#ifdef USE_LTDL
 #define _mcrypt_set_key mars_LTX__mcrypt_set_key
 #define _mcrypt_encrypt mars_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt mars_LTX__mcrypt_decrypt
@@ -28,6 +32,7 @@
 #define _mcrypt_get_algorithms_name mars_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test mars_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version mars_LTX__mcrypt_algorithm_version
+#endif
 
 /*
 Algorithm mars (mars.c)
@@ -201,50 +206,50 @@ static word32 b_tab[4] = {
  */
 
 #define f_mix(a,b,c,d)                  \
-        r = rotr(a, 8);                 \
+        r = rotr32(a, 8);                 \
         b ^= s_box[a & 255];            \
         b += s_box[(r & 255) + 256];    \
-        r = rotr(a, 16);                \
-        a  = rotr(a, 24);               \
+        r = rotr32(a, 16);                \
+        a  = rotr32(a, 24);               \
         c += s_box[r & 255];            \
         d ^= s_box[(a & 255) + 256]
 
 #define b_mix(a,b,c,d)                  \
-        r = rotl(a, 8);                 \
+        r = rotl32(a, 8);                 \
         b ^= s_box[(a & 255) + 256];    \
         c -= s_box[r & 255];            \
-        r = rotl(a, 16);                \
-        a  = rotl(a, 24);               \
+        r = rotl32(a, 16);                \
+        a  = rotl32(a, 24);               \
         d -= s_box[(r & 255) + 256];    \
         d ^= s_box[a & 255]
 
 #define f_ktr(a,b,c,d,i)    \
     m = a + key->l_key[i];       \
-    a = rotl(a, 13);        \
+    a = rotl32(a, 13);        \
     r = a * key->l_key[i + 1];   \
     l = s_box[m & 511];     \
-    r = rotl(r, 5);         \
-    c += rotl(m, r);        \
+    r = rotl32(r, 5);         \
+    c += rotl32(m, r);        \
     l ^= r;                 \
-    r = rotl(r, 5);         \
+    r = rotl32(r, 5);         \
     l ^= r;                 \
     d ^= r;                 \
-    b += rotl(l, r)
+    b += rotl32(l, r)
 
 #define r_ktr(a,b,c,d,i)    \
     r = a * key->l_key[i + 1];   \
-    a = rotr(a, 13);        \
+    a = rotr32(a, 13);        \
     m = a + key->l_key[i];       \
     l = s_box[m & 511];     \
-    r = rotl(r, 5);         \
+    r = rotl32(r, 5);         \
     l ^= r;                 \
-    c -= rotl(m, r);        \
-    r = rotl(r, 5);         \
+    c -= rotl32(m, r);        \
+    r = rotl32(r, 5);         \
     l ^= r;                 \
     d ^= r;                 \
-    b -= rotl(l, r)
+    b -= rotl32(l, r)
 
-void _mcrypt_set_key(MARS_KEY * key, const word32 * in_key,
+int _mcrypt_set_key(MARS_KEY * key, const word32 * in_key,
 		     const word32 key_len)
 {
 	word32 i, j, m;
@@ -252,11 +257,11 @@ void _mcrypt_set_key(MARS_KEY * key, const word32 * in_key,
 	m = (key_len * 8) / 32;
 
 	if (m < 4 || m > 14)
-		return;
+		return -1;
 
 	for (i = 0; i < m; ++i)
 #ifdef WORDS_BIGENDIAN
-		key->t_key[i] = byteswap(in_key[i]);
+		key->t_key[i] = byteswap32(in_key[i]);
 #else
 		key->t_key[i] = in_key[i];
 #endif
@@ -269,7 +274,7 @@ void _mcrypt_set_key(MARS_KEY * key, const word32 * in_key,
 		for (j = 0; j < 15; ++j)
 
 			key->t_key[j] ^=
-			    rotl(key->t_key[im7[j]] ^ key->t_key[im2[j]],
+			    rotl32(key->t_key[im7[j]] ^ key->t_key[im2[j]],
 				 3) ^ (4 * j + i);
 
 		for (m = 0; m < 4; ++m)
@@ -277,7 +282,7 @@ void _mcrypt_set_key(MARS_KEY * key, const word32 * in_key,
 			for (j = 0; j < 15; ++j)
 
 				key->t_key[j] =
-				    rotl(key->t_key[j] +
+				    rotl32(key->t_key[j] +
 					 s_box[key->t_key[im1[j]] & 511],
 					 9);
 
@@ -302,7 +307,7 @@ void _mcrypt_set_key(MARS_KEY * key, const word32 * in_key,
 			m &= 0xfffffffc;
 
 			j ^=
-			    (rotl
+			    (rotl32
 			     (b_tab[key->l_key[i] & 3],
 			      key->l_key[i - 1]) & m);
 		}
@@ -310,7 +315,7 @@ void _mcrypt_set_key(MARS_KEY * key, const word32 * in_key,
 		key->l_key[i] = j;
 	}
 
-	return;
+	return 0;
 }
 
 void _mcrypt_encrypt(MARS_KEY * key, word32 * blk)
@@ -318,10 +323,10 @@ void _mcrypt_encrypt(MARS_KEY * key, word32 * blk)
 	word32 a, b, c, d, l, m, r;
 
 #ifdef WORDS_BIGENDIAN
-	a = byteswap(blk[0]) + key->l_key[0];
-	b = byteswap(blk[1]) + key->l_key[1];
-	c = byteswap(blk[2]) + key->l_key[2];
-	d = byteswap(blk[3]) + key->l_key[3];
+	a = byteswap32(blk[0]) + key->l_key[0];
+	b = byteswap32(blk[1]) + key->l_key[1];
+	c = byteswap32(blk[2]) + key->l_key[2];
+	d = byteswap32(blk[3]) + key->l_key[3];
 #else
 	a = blk[0] + key->l_key[0];
 	b = blk[1] + key->l_key[1];
@@ -373,10 +378,10 @@ void _mcrypt_encrypt(MARS_KEY * key, word32 * blk)
 	b_mix(d, a, b, c);
 
 #ifdef WORDS_BIGENDIAN
-	blk[0] = byteswap(a - key->l_key[36]);
-	blk[1] = byteswap(b - key->l_key[37]);
-	blk[2] = byteswap(c - key->l_key[38]);
-	blk[3] = byteswap(d - key->l_key[39]);
+	blk[0] = byteswap32(a - key->l_key[36]);
+	blk[1] = byteswap32(b - key->l_key[37]);
+	blk[2] = byteswap32(c - key->l_key[38]);
+	blk[3] = byteswap32(d - key->l_key[39]);
 #else
 	blk[0] = a - key->l_key[36];
 	blk[1] = b - key->l_key[37];
@@ -391,10 +396,10 @@ void _mcrypt_decrypt(MARS_KEY * key, word32 * blk)
 	word32 a, b, c, d, l, m, r;
 
 #ifdef WORDS_BIGENDIAN
-	d = byteswap(blk[0]) + key->l_key[36];
-	c = byteswap(blk[1]) + key->l_key[37];
-	b = byteswap(blk[2]) + key->l_key[38];
-	a = byteswap(blk[3]) + key->l_key[39];
+	d = byteswap32(blk[0]) + key->l_key[36];
+	c = byteswap32(blk[1]) + key->l_key[37];
+	b = byteswap32(blk[2]) + key->l_key[38];
+	a = byteswap32(blk[3]) + key->l_key[39];
 #else
 	d = blk[0] + key->l_key[36];
 	c = blk[1] + key->l_key[37];
@@ -446,10 +451,10 @@ void _mcrypt_decrypt(MARS_KEY * key, word32 * blk)
 	b_mix(d, a, b, c);
 
 #ifdef WORDS_BIGENDIAN
-	blk[0] = byteswap(d - key->l_key[0]);
-	blk[1] = byteswap(c - key->l_key[1]);
-	blk[2] = byteswap(b - key->l_key[2]);
-	blk[3] = byteswap(a - key->l_key[3]);
+	blk[0] = byteswap32(d - key->l_key[0]);
+	blk[1] = byteswap32(c - key->l_key[1]);
+	blk[2] = byteswap32(b - key->l_key[2]);
+	blk[3] = byteswap32(a - key->l_key[3]);
 #else
 	blk[0] = d - key->l_key[0];
 	blk[1] = c - key->l_key[1];
@@ -481,10 +486,7 @@ int _mcrypt_get_key_size()
 
 char *_mcrypt_get_algorithms_name()
 {
-	char *x;
-	x = malloc(10);
-	strcpy(x, "Mars");
-	return x;
+	return "Mars";
 }
 
 #define CIPHER "ee250412268cbd418c02a0fce843a69c"
@@ -582,15 +584,12 @@ int _mcrypt_self_test(void)
 
 word32 _mcrypt_algorithm_version()
 {
-	return 20000229;
+	return 20010701;
 }
 
-int *_mcrypt_get_supported_key_sizes(int *len)
+static const int key_sizes[] = { 16, 24, 32 };
+const int *_mcrypt_get_supported_key_sizes(int *len)
 {
-	int *size = malloc(3 * sizeof(int));
-	size[0] = 16;
-	size[1] = 24;
-	size[2] = 32;
-	*len = 3;
-	return size;
+	*len = sizeof(key_sizes)/sizeof(int);
+	return key_sizes;
 }
